Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2497)

Unified Diff: chrome/browser/extensions/app_notification_manager.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/app_notification_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/app_notification_manager.h
diff --git a/chrome/browser/extensions/app_notification_manager.h b/chrome/browser/extensions/app_notification_manager.h
index f85f3abc65d50d7b2a8e22b8556ea4a912f28e7c..9a84b5ddb5986b9f71fd0cf7bb683f476eb23967 100644
--- a/chrome/browser/extensions/app_notification_manager.h
+++ b/chrome/browser/extensions/app_notification_manager.h
@@ -25,7 +25,10 @@
class PerfTimer;
class Profile;
+
+namespace csync {
class SyncErrorFactory;
+}
// This class keeps track of notifications for installed apps.
class AppNotificationManager
@@ -33,7 +36,7 @@ class AppNotificationManager
AppNotificationManager,
content::BrowserThread::DeleteOnUIThread>,
public content::NotificationObserver,
- public SyncableService {
+ public csync::SyncableService {
public:
static const unsigned int kMaxNotificationPerApp;
explicit AppNotificationManager(Profile* profile);
@@ -61,21 +64,22 @@ class AppNotificationManager
bool loaded() const { return notifications_.get() != NULL; }
- // SyncableService implementation.
+ // csync::SyncableService implementation.
- // Returns all syncable notifications from this model as SyncData.
- virtual SyncDataList GetAllSyncData(syncable::ModelType type) const OVERRIDE;
+ // Returns all syncable notifications from this model as csync::SyncData.
+ virtual csync::SyncDataList GetAllSyncData(
+ syncable::ModelType type) const OVERRIDE;
// Process notifications related changes from Sync, merging them into
// our model.
- virtual SyncError ProcessSyncChanges(
+ virtual csync::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const SyncChangeList& change_list) OVERRIDE;
+ const csync::SyncChangeList& change_list) OVERRIDE;
// Associate and merge sync data model with our data model.
- virtual SyncError MergeDataAndStartSyncing(
+ virtual csync::SyncError MergeDataAndStartSyncing(
syncable::ModelType type,
- const SyncDataList& initial_sync_data,
- scoped_ptr<SyncChangeProcessor> sync_processor,
- scoped_ptr<SyncErrorFactory> sync_error_factory) OVERRIDE;
+ const csync::SyncDataList& initial_sync_data,
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor,
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory) OVERRIDE;
virtual void StopSyncing(syncable::ModelType type) OVERRIDE;
private:
@@ -146,11 +150,11 @@ class AppNotificationManager
// Sends changes to syncer to remove all notifications in the given list.
void SyncClearAllChange(const AppNotificationList& list);
- // Converters from AppNotification to SyncData and vice versa.
- static SyncData CreateSyncDataFromNotification(
+ // Converters from AppNotification to csync::SyncData and vice versa.
+ static csync::SyncData CreateSyncDataFromNotification(
const AppNotification& notification);
static AppNotification* CreateNotificationFromSyncData(
- const SyncData& sync_data);
+ const csync::SyncData& sync_data);
Profile* profile_;
content::NotificationRegistrar registrar_;
@@ -160,10 +164,10 @@ class AppNotificationManager
scoped_ptr<AppNotificationStorage> storage_;
// Sync change processor we use to push all our changes.
- scoped_ptr<SyncChangeProcessor> sync_processor_;
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor_;
// Sync error handler that we use to create errors from.
- scoped_ptr<SyncErrorFactory> sync_error_factory_;
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory_;
// Whether the sync model is associated with the local model.
// In other words, whether we are ready to apply sync changes.
« no previous file with comments | « no previous file | chrome/browser/extensions/app_notification_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698